@@ -16,8 +16,8 @@ QTEST_GUILESS_MAIN(SaveRulesJobTest)
 
 void compareFile(const QString &name)
 {
-    const QString refFile = QLatin1String(KDEBUGSETTINGS_DATA_DIR) + QLatin1Char('/') + name + QStringLiteral(".ref");
-    const QString generatedFile = QLatin1String(KDEBUGSETTINGS_BINARY_DATA_DIR) + QLatin1Char('/') + name + QStringLiteral("-generated.ref");
+    const QString refFile = QLatin1StringView(KDEBUGSETTINGS_DATA_DIR) + QLatin1Char('/') + name + QStringLiteral(".ref");
+    const QString generatedFile = QLatin1StringView(KDEBUGSETTINGS_BINARY_DATA_DIR) + QLatin1Char('/') + name + QStringLiteral("-generated.ref");
     QProcess proc;
 
 #ifdef _WIN32
@@ -63,7 +63,7 @@ void SaveRulesJobTest::shouldSaveLoadRules()
 {
     QFETCH(QString, filename);
     LoadCategoriesJob job;
-    job.setFileName(QLatin1String(KDEBUGSETTINGS_DATA_DIR) + QLatin1Char('/') + filename + QStringLiteral(".ini"));
+    job.setFileName(QLatin1StringView(KDEBUGSETTINGS_DATA_DIR) + QLatin1Char('/') + filename + QStringLiteral(".ini"));
     job.start();
 
     const LoggingCategory::List customCategories = job.customCategories();
@@ -71,8 +71,8 @@ void SaveRulesJobTest::shouldSaveLoadRules()
     const LoggingCategory::List qtKdeCategories = job.qtKdeCategories();
 
     SaveRulesJob saveJob;
-    QDir().mkpath(QLatin1String(KDEBUGSETTINGS_BINARY_DATA_DIR));
-    saveJob.setFileName(QLatin1String(KDEBUGSETTINGS_BINARY_DATA_DIR) + QLatin1Char('/') + filename + QStringLiteral("-generated.ref"));
+    QDir().mkpath(QLatin1StringView(KDEBUGSETTINGS_BINARY_DATA_DIR));
+    saveJob.setFileName(QLatin1StringView(KDEBUGSETTINGS_BINARY_DATA_DIR) + QLatin1Char('/') + filename + QStringLiteral("-generated.ref"));
     qDebug() << " save " << saveJob.fileName();
     saveJob.setListCustom(customCategories);
     saveJob.setListKde(qtKdeCategories);
